@@ -47,7 +47,6 @@ use Encode qw( decode_utf8 );
 use JSON;
 use LWP::UserAgent;
 use Params::Validate qw(:all);
-use Plack::Session;
 use Try::Tiny;
 
 # methods/attributes not defined in this module will be inherited from:
@@ -101,6 +100,26 @@ sub context {
 }
 
 
+=head2 session
+
+=cut
+
+sub session {
+    my $self = shift;
+    return $self->request->{'env'}->{'psgix.session'};
+}
+
+
+=head2 session_id
+
+=cut
+
+sub session_id {
+    my $self = shift;
+    return $self->request->{'env'}->{'psgix.session.options'}->{'id'};
+}
+
+
 =head2 service_available
 
 This is the first method called on every incoming request.
@@ -128,14 +147,16 @@ sub content_types_provided {
 
 sub _render_response_html { 
     my ( $self ) = @_;
+    $log->debug( "Entering " . __PACKAGE__ . "::_render_response_html" );
+
     my $r = $self->request;
-    my $session = Plack::Session->new( $r->{'env'} );
-    my $ce = $session->get('currentUser');
-    my $cepriv = $session->get('currentUserPriv');
+    my $session = $r->{'env'}->{'psgix.session'};
+    my $ce = $session->{'currentUser'};
+    my $cepriv = $session->{'currentUserPriv'};
     my $entity;
     $entity = ( $r->path_info =~ m/test/i )
-        ? test_html( $ce, $cepriv )
-        : main_html( $ce, $cepriv );
+        ? $self->test_html( $ce, $cepriv )
+        : $self->main_html( $ce, $cepriv );
     return $entity;
 }
 
@@ -276,7 +297,7 @@ FIXME: might be worth spinning this off into a separate module.
 =cut
 
 sub main_html {
-    my ( $ce, $cepriv ) = @_;
+    my ( $self, $ce, $cepriv ) = @_;
 
     $cepriv = '' unless defined( $cepriv );
     $log->debug( "Entering " . __PACKAGE__ . "::main_html() with \$ce " .
@@ -289,7 +310,7 @@ sub main_html {
     $r .= '<link rel="stylesheet" type="text/css" href="/css/start.css" />';
 
     # Bring in RequireJS
-    $r .= _require_js($ce, $cepriv);
+    $r .= $self->_require_js($ce, $cepriv);
 
     $r .= '</head>';
     $r .= '<body>';
@@ -310,7 +331,7 @@ Generate html for running unit tests
 =cut
 
 sub test_html {
-    my ( $ce, $cepriv ) = @_;
+    my ( $self, $ce, $cepriv ) = @_;
 
     my $r = '';
     
@@ -320,7 +341,7 @@ sub test_html {
     $r .= '<link rel="stylesheet" type="text/css" href="/css/qunit.css" />';
 
     # Bring in RequireJS
-    $r .= _require_js($ce, $cepriv);
+    $r .= $self->_require_js($ce, $cepriv);
 
     $r .= '</head><body>';
     $r .= '<div id="qunit"></div>';
@@ -336,7 +357,7 @@ sub test_html {
 
 # HTML necessary for RequireJS
 sub _require_js {
-    my ( $ce, $cepriv ) = @_;
+    my ( $self, $ce, $cepriv ) = @_;
 
     my $r = '';
 
@@ -397,6 +418,13 @@ sub _require_js {
     $r .= 'loginDialogMaxLengthUsername: ' . $site->MFILE_WWW_LOGIN_DIALOG_MAXLENGTH_USERNAME . ',';
     $r .= 'loginDialogMaxLengthPassword: ' . $site->MFILE_WWW_LOGIN_DIALOG_MAXLENGTH_PASSWORD . ',';
 
+    # session data
+    $r .= 'displaySessionData: ' . ( $site->MFILE_WWW_DISPLAY_SESSION_DATA ? 'true' : 'false' ) . ',';
+    if ( $site->MFILE_WWW_DISPLAY_SESSION_DATA ) {
+        $r .= 'sessionID: \'' . $self->session_id . '\',';
+        $r .= 'sessionLastSeen: \'' . ( exists $self->session->{'last_seen'} ? $self->session->{'last_seen'} : 'never' ) . '\',';
+    }
+
     # REST server URI
     if ( defined( $site->DOCHAZKA_WWW_BACKEND_URI ) ) {
         $r .= 'restURI: \'' . $site->DOCHAZKA_WWW_BACKEND_URI . '\',';
