@@ -38,9 +38,11 @@
 
 define ([
     'lib',
+    'app/lib',
     'target'
 ], function (
     lib,
+    appLib,
     target
 ) {
 
@@ -49,36 +51,36 @@ define ([
     //
     var entries = {        
 
-        // read-only form entry no. 1
-        'browserEntry1': {
-            name: 'browserEntry1',
-            aclProfileRead: 'passerby',
-            text: 'Entry 1',
-            prop: 'prop1',
-            maxlen: 20
-        },
+            // read-only form entry no. 1
+            'browserEntry1': {
+                name: 'browserEntry1',
+                aclProfileRead: 'passerby',
+                text: 'Entry 1',
+                prop: 'prop1',
+                maxlen: 20
+            },
 
-        // read-write form entry no. 1
-        'browserEntry2': {
-            name: 'browserEntry2',
-            aclProfileRead: 'passerby',
-            text: 'Entry 2',
-            prop: 'prop2',
-            maxlen: 20
-        }
+            // read-write form entry no. 2
+            'browserEntry2': {
+                name: 'browserEntry2',
+                aclProfileRead: 'passerby',
+                text: 'Entry 2',
+                prop: 'prop2',
+                maxlen: 20
+            }
 
-    };
+        };
+
+    appLib.setBrowserSet([
+        { prop1: 'Some information here', prop2: 1234 },
+        { prop1: null, prop2: 'Some other info' },
+        { prop1: 'Mangled crab crackers', prop2: 'Umpteen whizzles' },
+        { prop1: 'Fandango', prop2: 'Professor!' },
+        { prop1: 'Emfeebled whipple weepers', prop2: 'A godg' },
+        { prop1: 'Wuppo wannabe', prop2: 'Jumbo jamb' }
+    ]);
     
     return function () {
-        // initialize sample result set
-        lib.holdObject([
-            { prop1: 'Some information here', prop2: 1234 },
-            { prop1: null, prop2: 'Some other info' },
-            { prop1: 'Mangled crab crackers', prop2: 'Umpteen whizzles' },
-            { prop1: 'Fandango', prop2: 'Professor!' },
-            { prop1: 'Emfeebled whipple weepers', prop2: 'A godg' },
-            { prop1: 'Wuppo wannabe', prop2: 'Jumbo jamb' }
-        ]);
 
         //
         // push dbrowser object definitions onto 'target' here
@@ -91,7 +93,7 @@ define ([
             'preamble': 'This is just an illustration',
             'aclProfile': 'passerby',
             'entries': [ entries.browserEntry1, entries.browserEntry2 ],
-            'hook': lib.holdObject,
+            'hook': appLib.getBrowserSet,
             'miniMenu': {
                 entries: ['demoEditFromBrowser'],
                 back: ['Done', 'demoSubmenu']
